==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebCircularGradientDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCircularGradientDescription } from "./WebCircularGradientDescription";
/**
 * @hidden
 */
export let WebCircularGradientDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCircularGradientDescriptionMetadata extends Base {
        static b(a) {
            if (WebCircularGradientDescriptionMetadata.a == null) {
                WebCircularGradientDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCircularGradientDescriptionMetadata.c(WebCircularGradientDescriptionMetadata.a);
            }
            if (a.j(WebCircularGradientDescriptionMetadata.a)) {
                return;
            }
            a.y(WebCircularGradientDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CircularGradient");
            a.item("__tagNameWC", "String:igc-circular-gradient");
            a.item("Offset", "String");
            a.item("Color", "String");
            a.item("Opacity", "Number:double");
        }
        static d(a) {
            WebCircularGradientDescriptionMetadata.b(a);
            a.aa("WebCircularGradient", () => new WebCircularGradientDescription());
            a.z("WebCircularGradient", WebCircularGradientDescriptionMetadata.a);
        }
    }
    WebCircularGradientDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCircularGradientDescriptionMetadata, 'WebCircularGradientDescriptionMetadata');
    WebCircularGradientDescriptionMetadata.a = null;
    return WebCircularGradientDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebCircularGradientDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCircularGradientDescription } from "./WebCircularGradientDescription";
/**
 * @hidden
 */
export let WebCircularGradientDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCircularGradientDescriptionMetadata extends Base {
        static b(a) {
            if (WebCircularGradientDescriptionMetadata.a == null) {
                WebCircularGradientDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCircularGradientDescriptionMetadata.c(WebCircularGradientDescriptionMetadata.a);
            }
            if (a.k(WebCircularGradientDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebCircularGradientDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CircularGradient");
            a.item("__tagNameWC", "String:igc-circular-gradient");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Offset", "String");
            a.item("Color", "String");
            a.item("Opacity", "Number:double");
        }
        static d(a) {
            WebCircularGradientDescriptionMetadata.b(a);
            a.ac("WebCircularGradient", () => new WebCircularGradientDescription());
            a.ab("WebCircularGradient", WebCircularGradientDescriptionMetadata.a);
        }
    }
    WebCircularGradientDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCircularGradientDescriptionMetadata, 'WebCircularGradientDescriptionMetadata');
    WebCircularGradientDescriptionMetadata.a = null;
    return WebCircularGradientDescriptionMetadata;
})();
